==> plugin.audio.intergalacticfm-1.0.3.zip: plugin.audio.intergalacticfm/README.md <==
Intergalactic FM Kodi Plugin
============================


![Intergalactic FM icon](icon.png?raw=true)


Installation
------------

Currently, installation is only possible by downloading ZIP file of this add-on on your system that runs Kodi and install it via the Kodi GUI.

  1. Download the ZIP file of this add-on with `wget https://github.com/PanderMusubi/plugin.audio.intergalacticfm/archive/master.zip` somewhere on your system that runs Kodi. Alternatively, you can download it in another way and copy it to your system running Kodi.
  2. In the Kodi GUI, go to `Add-ons` and choose `Install from zip file`. Then select the downloaded file `master.zip` and this add-on will be installed.
  3. If the add-on is not directly available, a restart of Kodi might be in place.

In the near future, this add-on will be a default add-on that can be installed directly from Kodi. That ill be announced at http://kodi.wiki/view/Add-on:Intergalactic_FM when it is included in the standard repostory of Kodi.


![Intergalactic FM fanart](fanart.jpg?raw=true)


Thanks
------

Thanks go to the authors of the original add-on that was developen for SomaFM for allowing to fork their work from https://github.com/Oderik/xbmc-somafm

Credits go to [Yulia Vilenksy](http://yuliavilensky.com) for persmission to use her photograph used as fanart.

For that and other projects using channels.xml and channels.json, I also developed a schema for XML and JSON to describe online radio station channels, see https://github.com/PanderMusubi/online-radio-channels For this, thanks go to SomaFM for allowing to describe their dataformat and reviewing my work.

Last but not least, thank you I-f and others for creating [Intergalactic FM](https://intergalacticfm.com) and embracing new initiatives and technologies to keep us all in musical orbit.

==> plugin.audio.intergalacticfm-1.0.4.zip: plugin.audio.intergalacticfm/README.md <==
Intergalactic FM Kodi Audio Plugin
==================================


![Intergalactic FM icon](icon.png?raw=true)


Installation
------------

Currently, installation is only possible by downloading ZIP file of this add-on on your system that runs Kodi and install it via the Kodi GUI.

  1. Download the ZIP file of this add-on with `wget https://github.com/PanderMusubi/plugin.audio.intergalacticfm/archive/master.zip` somewhere on your system that runs Kodi. Alternatively, you can download it in another way and copy it to your system running Kodi.
  2. In the Kodi GUI, go to `Add-ons` and choose `Install from zip file`. Then select the downloaded file `master.zip` and this add-on will be installed.
  3. If the add-on is not directly available, a restart of Kodi might be in place.

In the near future, this add-on will be a default add-on that can be installed directly from Kodi. That will be announced at http://kodi.wiki/view/Add-on:Intergalactic\_FM when it is included in the standard repostory of Kodi.


![Intergalactic FM fanart](fanart.jpg?raw=true)


See also
--------

See also the video plugin called Intergalactic FM TV at http://kodi.wiki/view/Add-on:IntergalacticFMTV and https://github.com/PanderMusubi/plugin.video.intergalacticfm


Thanks
------

Thanks go to the authors of the original add-on that was developed for SomaFM for allowing to fork their work from https://github.com/Oderik/xbmc-somafm

Credits go to [Yulia Vilenksy](http://yuliavilensky.com) for persmission to use her photograph used as fanart.

For that and other projects using channels.xml and channels.json, I also developed a schema for XML and JSON to describe online radio station channels, see https://github.com/PanderMusubi/online-radio-channels For this, thanks go to SomaFM for allowing to describe their dataformat and reviewing my work.

Last but not least, thank you I-f and others for creating [Intergalactic FM](https://intergalacticfm.com) and embracing new initiatives and technologies to keep us all in musical orbit.
